require_relative 'strawberry_api/configuration'
require_relative 'strawberry_api/http_client'
require_relative 'strawberry_api/client'
require_relative 'strawberry_api/version'

# module StrawberryAPI provides access to Strawberry REST API
#
# @author Pierre Lebrun <pierreyves.lebrun@gmail.com>
#
module StrawberryAPI

  # Return configuration
  # If it has not been configured yet, initialize configuration
  # @return [StrawberryAPI::Configuration] configuration object
  def self.config
    @config ||= StrawberryAPI::Configuration.new
  end

  # Set configuration
  #
  # @param config [StrawberryAPI::Configuration] configuration object
  # @return [StrawberryAPI::Configuration] configuration object
  def self.config=(config)
    raise TypeError unless config.is_a?(StrawberryAPI::Configuration)
    @config = config
  end

  # Configure some settings
  #
  # @yield [config] Given configuration object
  # @yieldparam config [StrawberryAPI::Configuration] configuration object
  #
  def self.configure
    yield(config)
  end
end
