module StrawberryAPI
  class Client < StrawberryAPI::HttpClient
    module ApiKeys

      attr_accessor :id
      attr_accessor :user_id
      attr_accessor :name
      attr_accessor :key
      attr_accessor :created_at
      attr_accessor :updated_at

      # Fetches user API keys
      #
      # @param [Integer] user_id Strawberry user id
      #
      # @return [Array<StrawberryAPI::ApiKey>] The fetched user API keys
      # 
      def api_key(user_id:)
        get("/users/#{user_id}/api_keys").parse['api_keys']&.map do |api_key|
          ApiKey.new(api_key)
        end
      end
      
      # Creates user API key
      #
      # @param [Integer] user_id Strawberry user id
      # @param [String] name Name of the API key to create
      #
      # @return [ApiKey] The created user API key
      # 
      def create_api_key(user_id:, name:)
        data = post("/users/#{user_id}/api_keys", body: {name: name}.to_json).parse['api_key']
        data.nil? ? nil : ApiKey.new(data)
      end

      # Deletes user API key
      #
      # @param [Integer] user_id Strawberry user id
      # @param [Integer] api_key_id Id of the API key to delete
      #
      # @return [Boolean] Success
      # 
      def delete_api_key(user_id:, api_key_id:)
        delete("/users/#{user_id}/api_keys/#{api_key_id}").success?
      end

    end
  end
end
