module StrawberryAPI
  class Client < StrawberryAPI::HttpClient
    module CustomMetadataFields

      # Fetches all custom metadata fields
      #
      #
      # @return [Array<StrawberryAPI::CustomMetadataField>] A list of custom metadata fields
      # 
      def custom_metadata_fields
        get("/custom_metadata_fields").parse['array']&.map do |field|
          CustomMetadataField.new(field)
        end
      end

      # Fetches a ustom metadata field
      #
      # @param [Integer] id Id of the ustom metadata field to retrieve
      #
      # @return [StrawberryAPI::Feature] The fetched ustom metadata field
      # 
      def custom_metadata_field(id:)
         data = get("/custom_metadata_fields/#{id}").parse['custommetadatafield']
         data.nil? ? nil : CustomMetadataField.new(data)
      end

      # Updates a custom metadata field
      #
      # @param [Interger] id Id of the custom metadata field to update
      # @param [Hash] options Hash of options
      #
      # @return [StrawberryAPI::CustomMetadataField] The updated custom metadata field
      # 
      def update_custom_metadata_field(id:, options: {})
        data = put("/custom_metadata_fields/#{id}", body: options.to_json).parse['custommetadatafield']
        data.nil? ? nil : CustomMetadataField.new(data)
      end

    end
  end
end